@@ -74,6 +74,14 @@ class __TwigTemplate_fc6a4bfd981f73775ff092fe495732f8 extends Template
         // line 19
         yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->outputHeadDeclarations();
         yield "
+
+    <script>
+        window.addEventListener('load', function () {
+            setTimeout(function () {
+                document.title = 'Cause Buzz';
+            }, 10);
+        });
+    </script>
 </head>
 ";
         yield from [];
